# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['SentryProjectArgs', 'SentryProject']

@pulumi.input_type
class SentryProjectArgs:
    def __init__(__self__, *,
                 organization: pulumi.Input[str],
                 digests_max_delay: Optional[pulumi.Input[int]] = None,
                 digests_min_delay: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 platform: Optional[pulumi.Input[str]] = None,
                 resolve_age: Optional[pulumi.Input[int]] = None,
                 slug: Optional[pulumi.Input[str]] = None,
                 team: Optional[pulumi.Input[str]] = None,
                 teams: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a SentryProject resource.
        :param pulumi.Input[str] organization: The slug of the organization the project belongs to.
        :param pulumi.Input[int] digests_max_delay: The maximum amount of time (in seconds) to wait between scheduling digests for delivery.
        :param pulumi.Input[int] digests_min_delay: The minimum amount of time (in seconds) to wait between scheduling digests for delivery after the initial scheduling.
        :param pulumi.Input[str] name: The name for the project.
        :param pulumi.Input[str] platform: The optional platform for this project.
        :param pulumi.Input[int] resolve_age: Hours in which an issue is automatically resolve if not seen after this amount of time.
        :param pulumi.Input[str] slug: The optional slug for this project.
        :param pulumi.Input[str] team: The slug of the team to create the project for. **Deprecated** Use `teams` instead.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] teams: The slugs of the teams to create the project for.
        """
        pulumi.set(__self__, "organization", organization)
        if digests_max_delay is not None:
            pulumi.set(__self__, "digests_max_delay", digests_max_delay)
        if digests_min_delay is not None:
            pulumi.set(__self__, "digests_min_delay", digests_min_delay)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if platform is not None:
            pulumi.set(__self__, "platform", platform)
        if resolve_age is not None:
            pulumi.set(__self__, "resolve_age", resolve_age)
        if slug is not None:
            pulumi.set(__self__, "slug", slug)
        if team is not None:
            warnings.warn("""Use `teams` instead.""", DeprecationWarning)
            pulumi.log.warn("""team is deprecated: Use `teams` instead.""")
        if team is not None:
            pulumi.set(__self__, "team", team)
        if teams is not None:
            pulumi.set(__self__, "teams", teams)

    @property
    @pulumi.getter
    def organization(self) -> pulumi.Input[str]:
        """
        The slug of the organization the project belongs to.
        """
        return pulumi.get(self, "organization")

    @organization.setter
    def organization(self, value: pulumi.Input[str]):
        pulumi.set(self, "organization", value)

    @property
    @pulumi.getter(name="digestsMaxDelay")
    def digests_max_delay(self) -> Optional[pulumi.Input[int]]:
        """
        The maximum amount of time (in seconds) to wait between scheduling digests for delivery.
        """
        return pulumi.get(self, "digests_max_delay")

    @digests_max_delay.setter
    def digests_max_delay(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "digests_max_delay", value)

    @property
    @pulumi.getter(name="digestsMinDelay")
    def digests_min_delay(self) -> Optional[pulumi.Input[int]]:
        """
        The minimum amount of time (in seconds) to wait between scheduling digests for delivery after the initial scheduling.
        """
        return pulumi.get(self, "digests_min_delay")

    @digests_min_delay.setter
    def digests_min_delay(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "digests_min_delay", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name for the project.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def platform(self) -> Optional[pulumi.Input[str]]:
        """
        The optional platform for this project.
        """
        return pulumi.get(self, "platform")

    @platform.setter
    def platform(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "platform", value)

    @property
    @pulumi.getter(name="resolveAge")
    def resolve_age(self) -> Optional[pulumi.Input[int]]:
        """
        Hours in which an issue is automatically resolve if not seen after this amount of time.
        """
        return pulumi.get(self, "resolve_age")

    @resolve_age.setter
    def resolve_age(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "resolve_age", value)

    @property
    @pulumi.getter
    def slug(self) -> Optional[pulumi.Input[str]]:
        """
        The optional slug for this project.
        """
        return pulumi.get(self, "slug")

    @slug.setter
    def slug(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "slug", value)

    @property
    @pulumi.getter
    @_utilities.deprecated("""Use `teams` instead.""")
    def team(self) -> Optional[pulumi.Input[str]]:
        """
        The slug of the team to create the project for. **Deprecated** Use `teams` instead.
        """
        return pulumi.get(self, "team")

    @team.setter
    def team(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "team", value)

    @property
    @pulumi.getter
    def teams(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The slugs of the teams to create the project for.
        """
        return pulumi.get(self, "teams")

    @teams.setter
    def teams(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "teams", value)


@pulumi.input_type
class _SentryProjectState:
    def __init__(__self__, *,
                 color: Optional[pulumi.Input[str]] = None,
                 digests_max_delay: Optional[pulumi.Input[int]] = None,
                 digests_min_delay: Optional[pulumi.Input[int]] = None,
                 features: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 internal_id: Optional[pulumi.Input[str]] = None,
                 is_bookmarked: Optional[pulumi.Input[bool]] = None,
                 is_public: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 platform: Optional[pulumi.Input[str]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 resolve_age: Optional[pulumi.Input[int]] = None,
                 slug: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 team: Optional[pulumi.Input[str]] = None,
                 teams: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering SentryProject resources.
        :param pulumi.Input[int] digests_max_delay: The maximum amount of time (in seconds) to wait between scheduling digests for delivery.
        :param pulumi.Input[int] digests_min_delay: The minimum amount of time (in seconds) to wait between scheduling digests for delivery after the initial scheduling.
        :param pulumi.Input[str] internal_id: The internal ID for this project.
        :param pulumi.Input[str] name: The name for the project.
        :param pulumi.Input[str] organization: The slug of the organization the project belongs to.
        :param pulumi.Input[str] platform: The optional platform for this project.
        :param pulumi.Input[str] project_id: Use `internal_id` instead.
        :param pulumi.Input[int] resolve_age: Hours in which an issue is automatically resolve if not seen after this amount of time.
        :param pulumi.Input[str] slug: The optional slug for this project.
        :param pulumi.Input[str] team: The slug of the team to create the project for. **Deprecated** Use `teams` instead.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] teams: The slugs of the teams to create the project for.
        """
        if color is not None:
            pulumi.set(__self__, "color", color)
        if digests_max_delay is not None:
            pulumi.set(__self__, "digests_max_delay", digests_max_delay)
        if digests_min_delay is not None:
            pulumi.set(__self__, "digests_min_delay", digests_min_delay)
        if features is not None:
            pulumi.set(__self__, "features", features)
        if internal_id is not None:
            pulumi.set(__self__, "internal_id", internal_id)
        if is_bookmarked is not None:
            warnings.warn("""is_bookmarked is no longer used""", DeprecationWarning)
            pulumi.log.warn("""is_bookmarked is deprecated: is_bookmarked is no longer used""")
        if is_bookmarked is not None:
            pulumi.set(__self__, "is_bookmarked", is_bookmarked)
        if is_public is not None:
            pulumi.set(__self__, "is_public", is_public)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if organization is not None:
            pulumi.set(__self__, "organization", organization)
        if platform is not None:
            pulumi.set(__self__, "platform", platform)
        if project_id is not None:
            warnings.warn("""Use `internal_id` instead.""", DeprecationWarning)
            pulumi.log.warn("""project_id is deprecated: Use `internal_id` instead.""")
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if resolve_age is not None:
            pulumi.set(__self__, "resolve_age", resolve_age)
        if slug is not None:
            pulumi.set(__self__, "slug", slug)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if team is not None:
            warnings.warn("""Use `teams` instead.""", DeprecationWarning)
            pulumi.log.warn("""team is deprecated: Use `teams` instead.""")
        if team is not None:
            pulumi.set(__self__, "team", team)
        if teams is not None:
            pulumi.set(__self__, "teams", teams)

    @property
    @pulumi.getter
    def color(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "color")

    @color.setter
    def color(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "color", value)

    @property
    @pulumi.getter(name="digestsMaxDelay")
    def digests_max_delay(self) -> Optional[pulumi.Input[int]]:
        """
        The maximum amount of time (in seconds) to wait between scheduling digests for delivery.
        """
        return pulumi.get(self, "digests_max_delay")

    @digests_max_delay.setter
    def digests_max_delay(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "digests_max_delay", value)

    @property
    @pulumi.getter(name="digestsMinDelay")
    def digests_min_delay(self) -> Optional[pulumi.Input[int]]:
        """
        The minimum amount of time (in seconds) to wait between scheduling digests for delivery after the initial scheduling.
        """
        return pulumi.get(self, "digests_min_delay")

    @digests_min_delay.setter
    def digests_min_delay(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "digests_min_delay", value)

    @property
    @pulumi.getter
    def features(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "features")

    @features.setter
    def features(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "features", value)

    @property
    @pulumi.getter(name="internalId")
    def internal_id(self) -> Optional[pulumi.Input[str]]:
        """
        The internal ID for this project.
        """
        return pulumi.get(self, "internal_id")

    @internal_id.setter
    def internal_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "internal_id", value)

    @property
    @pulumi.getter(name="isBookmarked")
    @_utilities.deprecated("""is_bookmarked is no longer used""")
    def is_bookmarked(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "is_bookmarked")

    @is_bookmarked.setter
    def is_bookmarked(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_bookmarked", value)

    @property
    @pulumi.getter(name="isPublic")
    def is_public(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "is_public")

    @is_public.setter
    def is_public(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_public", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name for the project.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def organization(self) -> Optional[pulumi.Input[str]]:
        """
        The slug of the organization the project belongs to.
        """
        return pulumi.get(self, "organization")

    @organization.setter
    def organization(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "organization", value)

    @property
    @pulumi.getter
    def platform(self) -> Optional[pulumi.Input[str]]:
        """
        The optional platform for this project.
        """
        return pulumi.get(self, "platform")

    @platform.setter
    def platform(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "platform", value)

    @property
    @pulumi.getter(name="projectId")
    @_utilities.deprecated("""Use `internal_id` instead.""")
    def project_id(self) -> Optional[pulumi.Input[str]]:
        """
        Use `internal_id` instead.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter(name="resolveAge")
    def resolve_age(self) -> Optional[pulumi.Input[int]]:
        """
        Hours in which an issue is automatically resolve if not seen after this amount of time.
        """
        return pulumi.get(self, "resolve_age")

    @resolve_age.setter
    def resolve_age(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "resolve_age", value)

    @property
    @pulumi.getter
    def slug(self) -> Optional[pulumi.Input[str]]:
        """
        The optional slug for this project.
        """
        return pulumi.get(self, "slug")

    @slug.setter
    def slug(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "slug", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    @_utilities.deprecated("""Use `teams` instead.""")
    def team(self) -> Optional[pulumi.Input[str]]:
        """
        The slug of the team to create the project for. **Deprecated** Use `teams` instead.
        """
        return pulumi.get(self, "team")

    @team.setter
    def team(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "team", value)

    @property
    @pulumi.getter
    def teams(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The slugs of the teams to create the project for.
        """
        return pulumi.get(self, "teams")

    @teams.setter
    def teams(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "teams", value)


class SentryProject(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 digests_max_delay: Optional[pulumi.Input[int]] = None,
                 digests_min_delay: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 platform: Optional[pulumi.Input[str]] = None,
                 resolve_age: Optional[pulumi.Input[int]] = None,
                 slug: Optional[pulumi.Input[str]] = None,
                 team: Optional[pulumi.Input[str]] = None,
                 teams: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        Sentry Project resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_sentry as sentry

        # Create a project
        default = sentry.SentryProject("default",
            organization="my-organization",
            teams=[
                "my-first-team",
                "my-second-team",
            ],
            name="Web App",
            slug="web-app",
            platform="javascript",
            resolve_age=720)
        ```

        ## Import

        import using the organization and team slugs from the URL:

        https://sentry.io/settings/[org-slug]/projects/[project-slug]/

        ```sh
        $ pulumi import sentry:index/sentryProject:SentryProject default org-slug/project-slug
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] digests_max_delay: The maximum amount of time (in seconds) to wait between scheduling digests for delivery.
        :param pulumi.Input[int] digests_min_delay: The minimum amount of time (in seconds) to wait between scheduling digests for delivery after the initial scheduling.
        :param pulumi.Input[str] name: The name for the project.
        :param pulumi.Input[str] organization: The slug of the organization the project belongs to.
        :param pulumi.Input[str] platform: The optional platform for this project.
        :param pulumi.Input[int] resolve_age: Hours in which an issue is automatically resolve if not seen after this amount of time.
        :param pulumi.Input[str] slug: The optional slug for this project.
        :param pulumi.Input[str] team: The slug of the team to create the project for. **Deprecated** Use `teams` instead.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] teams: The slugs of the teams to create the project for.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SentryProjectArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Sentry Project resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_sentry as sentry

        # Create a project
        default = sentry.SentryProject("default",
            organization="my-organization",
            teams=[
                "my-first-team",
                "my-second-team",
            ],
            name="Web App",
            slug="web-app",
            platform="javascript",
            resolve_age=720)
        ```

        ## Import

        import using the organization and team slugs from the URL:

        https://sentry.io/settings/[org-slug]/projects/[project-slug]/

        ```sh
        $ pulumi import sentry:index/sentryProject:SentryProject default org-slug/project-slug
        ```

        :param str resource_name: The name of the resource.
        :param SentryProjectArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SentryProjectArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 digests_max_delay: Optional[pulumi.Input[int]] = None,
                 digests_min_delay: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 platform: Optional[pulumi.Input[str]] = None,
                 resolve_age: Optional[pulumi.Input[int]] = None,
                 slug: Optional[pulumi.Input[str]] = None,
                 team: Optional[pulumi.Input[str]] = None,
                 teams: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SentryProjectArgs.__new__(SentryProjectArgs)

            __props__.__dict__["digests_max_delay"] = digests_max_delay
            __props__.__dict__["digests_min_delay"] = digests_min_delay
            __props__.__dict__["name"] = name
            if organization is None and not opts.urn:
                raise TypeError("Missing required property 'organization'")
            __props__.__dict__["organization"] = organization
            __props__.__dict__["platform"] = platform
            __props__.__dict__["resolve_age"] = resolve_age
            __props__.__dict__["slug"] = slug
            __props__.__dict__["team"] = team
            __props__.__dict__["teams"] = teams
            __props__.__dict__["color"] = None
            __props__.__dict__["features"] = None
            __props__.__dict__["internal_id"] = None
            __props__.__dict__["is_bookmarked"] = None
            __props__.__dict__["is_public"] = None
            __props__.__dict__["project_id"] = None
            __props__.__dict__["status"] = None
        super(SentryProject, __self__).__init__(
            'sentry:index/sentryProject:SentryProject',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            color: Optional[pulumi.Input[str]] = None,
            digests_max_delay: Optional[pulumi.Input[int]] = None,
            digests_min_delay: Optional[pulumi.Input[int]] = None,
            features: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            internal_id: Optional[pulumi.Input[str]] = None,
            is_bookmarked: Optional[pulumi.Input[bool]] = None,
            is_public: Optional[pulumi.Input[bool]] = None,
            name: Optional[pulumi.Input[str]] = None,
            organization: Optional[pulumi.Input[str]] = None,
            platform: Optional[pulumi.Input[str]] = None,
            project_id: Optional[pulumi.Input[str]] = None,
            resolve_age: Optional[pulumi.Input[int]] = None,
            slug: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            team: Optional[pulumi.Input[str]] = None,
            teams: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None) -> 'SentryProject':
        """
        Get an existing SentryProject resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] digests_max_delay: The maximum amount of time (in seconds) to wait between scheduling digests for delivery.
        :param pulumi.Input[int] digests_min_delay: The minimum amount of time (in seconds) to wait between scheduling digests for delivery after the initial scheduling.
        :param pulumi.Input[str] internal_id: The internal ID for this project.
        :param pulumi.Input[str] name: The name for the project.
        :param pulumi.Input[str] organization: The slug of the organization the project belongs to.
        :param pulumi.Input[str] platform: The optional platform for this project.
        :param pulumi.Input[str] project_id: Use `internal_id` instead.
        :param pulumi.Input[int] resolve_age: Hours in which an issue is automatically resolve if not seen after this amount of time.
        :param pulumi.Input[str] slug: The optional slug for this project.
        :param pulumi.Input[str] team: The slug of the team to create the project for. **Deprecated** Use `teams` instead.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] teams: The slugs of the teams to create the project for.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SentryProjectState.__new__(_SentryProjectState)

        __props__.__dict__["color"] = color
        __props__.__dict__["digests_max_delay"] = digests_max_delay
        __props__.__dict__["digests_min_delay"] = digests_min_delay
        __props__.__dict__["features"] = features
        __props__.__dict__["internal_id"] = internal_id
        __props__.__dict__["is_bookmarked"] = is_bookmarked
        __props__.__dict__["is_public"] = is_public
        __props__.__dict__["name"] = name
        __props__.__dict__["organization"] = organization
        __props__.__dict__["platform"] = platform
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["resolve_age"] = resolve_age
        __props__.__dict__["slug"] = slug
        __props__.__dict__["status"] = status
        __props__.__dict__["team"] = team
        __props__.__dict__["teams"] = teams
        return SentryProject(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def color(self) -> pulumi.Output[str]:
        return pulumi.get(self, "color")

    @property
    @pulumi.getter(name="digestsMaxDelay")
    def digests_max_delay(self) -> pulumi.Output[int]:
        """
        The maximum amount of time (in seconds) to wait between scheduling digests for delivery.
        """
        return pulumi.get(self, "digests_max_delay")

    @property
    @pulumi.getter(name="digestsMinDelay")
    def digests_min_delay(self) -> pulumi.Output[int]:
        """
        The minimum amount of time (in seconds) to wait between scheduling digests for delivery after the initial scheduling.
        """
        return pulumi.get(self, "digests_min_delay")

    @property
    @pulumi.getter
    def features(self) -> pulumi.Output[Sequence[str]]:
        return pulumi.get(self, "features")

    @property
    @pulumi.getter(name="internalId")
    def internal_id(self) -> pulumi.Output[str]:
        """
        The internal ID for this project.
        """
        return pulumi.get(self, "internal_id")

    @property
    @pulumi.getter(name="isBookmarked")
    @_utilities.deprecated("""is_bookmarked is no longer used""")
    def is_bookmarked(self) -> pulumi.Output[bool]:
        return pulumi.get(self, "is_bookmarked")

    @property
    @pulumi.getter(name="isPublic")
    def is_public(self) -> pulumi.Output[bool]:
        return pulumi.get(self, "is_public")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name for the project.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def organization(self) -> pulumi.Output[str]:
        """
        The slug of the organization the project belongs to.
        """
        return pulumi.get(self, "organization")

    @property
    @pulumi.getter
    def platform(self) -> pulumi.Output[str]:
        """
        The optional platform for this project.
        """
        return pulumi.get(self, "platform")

    @property
    @pulumi.getter(name="projectId")
    @_utilities.deprecated("""Use `internal_id` instead.""")
    def project_id(self) -> pulumi.Output[str]:
        """
        Use `internal_id` instead.
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter(name="resolveAge")
    def resolve_age(self) -> pulumi.Output[int]:
        """
        Hours in which an issue is automatically resolve if not seen after this amount of time.
        """
        return pulumi.get(self, "resolve_age")

    @property
    @pulumi.getter
    def slug(self) -> pulumi.Output[str]:
        """
        The optional slug for this project.
        """
        return pulumi.get(self, "slug")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    @_utilities.deprecated("""Use `teams` instead.""")
    def team(self) -> pulumi.Output[Optional[str]]:
        """
        The slug of the team to create the project for. **Deprecated** Use `teams` instead.
        """
        return pulumi.get(self, "team")

    @property
    @pulumi.getter
    def teams(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        The slugs of the teams to create the project for.
        """
        return pulumi.get(self, "teams")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['SentryIssueAlertArgs', 'SentryIssueAlert']

@pulumi.input_type
class SentryIssueAlertArgs:
    def __init__(__self__, *,
                 action_match: pulumi.Input[str],
                 actions: pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]],
                 conditions: pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]],
                 filter_match: pulumi.Input[str],
                 frequency: pulumi.Input[int],
                 organization: pulumi.Input[str],
                 project: pulumi.Input[str],
                 environment: Optional[pulumi.Input[str]] = None,
                 filters: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a SentryIssueAlert resource.
        :param pulumi.Input[str] action_match: Trigger actions when an event is captured by Sentry and `any` or `all` of the specified conditions happen.
        :param pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]] actions: List of actions.
        :param pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]] conditions: List of conditions.
        :param pulumi.Input[str] filter_match: Trigger actions if `all`, `any`, or `none` of the specified filters match.
        :param pulumi.Input[int] frequency: Perform actions at most once every `X` minutes for this issue. Defaults to `30`.
        :param pulumi.Input[str] organization: The slug of the organization the issue alert belongs to.
        :param pulumi.Input[str] project: The slug of the project to create the issue alert for.
        :param pulumi.Input[str] environment: Perform issue alert in a specific environment.
        :param pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]] filters: List of filters.
        :param pulumi.Input[str] name: The issue alert name.
        """
        pulumi.set(__self__, "action_match", action_match)
        pulumi.set(__self__, "actions", actions)
        pulumi.set(__self__, "conditions", conditions)
        pulumi.set(__self__, "filter_match", filter_match)
        pulumi.set(__self__, "frequency", frequency)
        pulumi.set(__self__, "organization", organization)
        pulumi.set(__self__, "project", project)
        if environment is not None:
            pulumi.set(__self__, "environment", environment)
        if filters is not None:
            pulumi.set(__self__, "filters", filters)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="actionMatch")
    def action_match(self) -> pulumi.Input[str]:
        """
        Trigger actions when an event is captured by Sentry and `any` or `all` of the specified conditions happen.
        """
        return pulumi.get(self, "action_match")

    @action_match.setter
    def action_match(self, value: pulumi.Input[str]):
        pulumi.set(self, "action_match", value)

    @property
    @pulumi.getter
    def actions(self) -> pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]:
        """
        List of actions.
        """
        return pulumi.get(self, "actions")

    @actions.setter
    def actions(self, value: pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]):
        pulumi.set(self, "actions", value)

    @property
    @pulumi.getter
    def conditions(self) -> pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]:
        """
        List of conditions.
        """
        return pulumi.get(self, "conditions")

    @conditions.setter
    def conditions(self, value: pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]):
        pulumi.set(self, "conditions", value)

    @property
    @pulumi.getter(name="filterMatch")
    def filter_match(self) -> pulumi.Input[str]:
        """
        Trigger actions if `all`, `any`, or `none` of the specified filters match.
        """
        return pulumi.get(self, "filter_match")

    @filter_match.setter
    def filter_match(self, value: pulumi.Input[str]):
        pulumi.set(self, "filter_match", value)

    @property
    @pulumi.getter
    def frequency(self) -> pulumi.Input[int]:
        """
        Perform actions at most once every `X` minutes for this issue. Defaults to `30`.
        """
        return pulumi.get(self, "frequency")

    @frequency.setter
    def frequency(self, value: pulumi.Input[int]):
        pulumi.set(self, "frequency", value)

    @property
    @pulumi.getter
    def organization(self) -> pulumi.Input[str]:
        """
        The slug of the organization the issue alert belongs to.
        """
        return pulumi.get(self, "organization")

    @organization.setter
    def organization(self, value: pulumi.Input[str]):
        pulumi.set(self, "organization", value)

    @property
    @pulumi.getter
    def project(self) -> pulumi.Input[str]:
        """
        The slug of the project to create the issue alert for.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[str]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter
    def environment(self) -> Optional[pulumi.Input[str]]:
        """
        Perform issue alert in a specific environment.
        """
        return pulumi.get(self, "environment")

    @environment.setter
    def environment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "environment", value)

    @property
    @pulumi.getter
    def filters(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]]:
        """
        List of filters.
        """
        return pulumi.get(self, "filters")

    @filters.setter
    def filters(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]]):
        pulumi.set(self, "filters", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The issue alert name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _SentryIssueAlertState:
    def __init__(__self__, *,
                 action_match: Optional[pulumi.Input[str]] = None,
                 actions: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]] = None,
                 conditions: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]] = None,
                 environment: Optional[pulumi.Input[str]] = None,
                 filter_match: Optional[pulumi.Input[str]] = None,
                 filters: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]] = None,
                 frequency: Optional[pulumi.Input[int]] = None,
                 internal_id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 projects: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering SentryIssueAlert resources.
        :param pulumi.Input[str] action_match: Trigger actions when an event is captured by Sentry and `any` or `all` of the specified conditions happen.
        :param pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]] actions: List of actions.
        :param pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]] conditions: List of conditions.
        :param pulumi.Input[str] environment: Perform issue alert in a specific environment.
        :param pulumi.Input[str] filter_match: Trigger actions if `all`, `any`, or `none` of the specified filters match.
        :param pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]] filters: List of filters.
        :param pulumi.Input[int] frequency: Perform actions at most once every `X` minutes for this issue. Defaults to `30`.
        :param pulumi.Input[str] internal_id: The internal ID for this issue alert.
        :param pulumi.Input[str] name: The issue alert name.
        :param pulumi.Input[str] organization: The slug of the organization the issue alert belongs to.
        :param pulumi.Input[str] project: The slug of the project to create the issue alert for.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] projects: Use `project` (singular) instead.
        """
        if action_match is not None:
            pulumi.set(__self__, "action_match", action_match)
        if actions is not None:
            pulumi.set(__self__, "actions", actions)
        if conditions is not None:
            pulumi.set(__self__, "conditions", conditions)
        if environment is not None:
            pulumi.set(__self__, "environment", environment)
        if filter_match is not None:
            pulumi.set(__self__, "filter_match", filter_match)
        if filters is not None:
            pulumi.set(__self__, "filters", filters)
        if frequency is not None:
            pulumi.set(__self__, "frequency", frequency)
        if internal_id is not None:
            pulumi.set(__self__, "internal_id", internal_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if organization is not None:
            pulumi.set(__self__, "organization", organization)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if projects is not None:
            warnings.warn("""Use `project` (singular) instead.""", DeprecationWarning)
            pulumi.log.warn("""projects is deprecated: Use `project` (singular) instead.""")
        if projects is not None:
            pulumi.set(__self__, "projects", projects)

    @property
    @pulumi.getter(name="actionMatch")
    def action_match(self) -> Optional[pulumi.Input[str]]:
        """
        Trigger actions when an event is captured by Sentry and `any` or `all` of the specified conditions happen.
        """
        return pulumi.get(self, "action_match")

    @action_match.setter
    def action_match(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "action_match", value)

    @property
    @pulumi.getter
    def actions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]]:
        """
        List of actions.
        """
        return pulumi.get(self, "actions")

    @actions.setter
    def actions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]]):
        pulumi.set(self, "actions", value)

    @property
    @pulumi.getter
    def conditions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]]:
        """
        List of conditions.
        """
        return pulumi.get(self, "conditions")

    @conditions.setter
    def conditions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]]):
        pulumi.set(self, "conditions", value)

    @property
    @pulumi.getter
    def environment(self) -> Optional[pulumi.Input[str]]:
        """
        Perform issue alert in a specific environment.
        """
        return pulumi.get(self, "environment")

    @environment.setter
    def environment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "environment", value)

    @property
    @pulumi.getter(name="filterMatch")
    def filter_match(self) -> Optional[pulumi.Input[str]]:
        """
        Trigger actions if `all`, `any`, or `none` of the specified filters match.
        """
        return pulumi.get(self, "filter_match")

    @filter_match.setter
    def filter_match(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "filter_match", value)

    @property
    @pulumi.getter
    def filters(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]]:
        """
        List of filters.
        """
        return pulumi.get(self, "filters")

    @filters.setter
    def filters(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]]):
        pulumi.set(self, "filters", value)

    @property
    @pulumi.getter
    def frequency(self) -> Optional[pulumi.Input[int]]:
        """
        Perform actions at most once every `X` minutes for this issue. Defaults to `30`.
        """
        return pulumi.get(self, "frequency")

    @frequency.setter
    def frequency(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "frequency", value)

    @property
    @pulumi.getter(name="internalId")
    def internal_id(self) -> Optional[pulumi.Input[str]]:
        """
        The internal ID for this issue alert.
        """
        return pulumi.get(self, "internal_id")

    @internal_id.setter
    def internal_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "internal_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The issue alert name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def organization(self) -> Optional[pulumi.Input[str]]:
        """
        The slug of the organization the issue alert belongs to.
        """
        return pulumi.get(self, "organization")

    @organization.setter
    def organization(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "organization", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[str]]:
        """
        The slug of the project to create the issue alert for.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter
    @_utilities.deprecated("""Use `project` (singular) instead.""")
    def projects(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Use `project` (singular) instead.
        """
        return pulumi.get(self, "projects")

    @projects.setter
    def projects(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "projects", value)


class SentryIssueAlert(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 action_match: Optional[pulumi.Input[str]] = None,
                 actions: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]] = None,
                 conditions: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]] = None,
                 environment: Optional[pulumi.Input[str]] = None,
                 filter_match: Optional[pulumi.Input[str]] = None,
                 filters: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]] = None,
                 frequency: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Sentry Issue Alert resource. Note that there's no public documentation for the values of conditions, filters, and actions. You can either inspect the request payload sent when creating or editing an issue alert on Sentry or inspect [Sentry's rules registry in the source code](https://github.com/getsentry/sentry/tree/master/src/sentry/rules). Since v0.11.2, you should also omit the name property of each condition, filter, and action.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_sentry as sentry
        import pulumiverse_sentry as sentry

        # Retrieve a Slack integration
        slack = sentry.get_sentry_organization_integration(organization=test["organization"],
            provider_key="slack",
            name="Slack Workspace")
        main = sentry.SentryIssueAlert("main",
            organization=main_sentry_project["organization"],
            project=main_sentry_project["id"],
            name="My issue alert",
            action_match="any",
            filter_match="any",
            frequency=30,
            conditions=[
                {
                    "id": "sentry.rules.conditions.first_seen_event.FirstSeenEventCondition",
                },
                {
                    "id": "sentry.rules.conditions.regression_event.RegressionEventCondition",
                },
                {
                    "id": "sentry.rules.conditions.event_frequency.EventFrequencyCondition",
                    "value": "100",
                    "comparisonType": "count",
                    "interval": "1h",
                },
                {
                    "id": "sentry.rules.conditions.event_frequency.EventUniqueUserFrequencyCondition",
                    "value": "100",
                    "comparisonType": "count",
                    "interval": "1h",
                },
                {
                    "id": "sentry.rules.conditions.event_frequency.EventFrequencyPercentCondition",
                    "value": "50.0",
                    "comparisonType": "count",
                    "interval": "1h",
                },
            ],
            filters=[
                {
                    "id": "sentry.rules.filters.age_comparison.AgeComparisonFilter",
                    "value": "10",
                    "time": "minute",
                    "comparison_type": "older",
                },
                {
                    "id": "sentry.rules.filters.issue_occurrences.IssueOccurrencesFilter",
                    "value": "10",
                },
                {
                    "id": "sentry.rules.filters.assigned_to.AssignedToFilter",
                    "targetType": "Team",
                    "targetIdentifier": main_sentry_team["teamId"],
                },
                {
                    "id": "sentry.rules.filters.latest_release.LatestReleaseFilter",
                },
                {
                    "id": "sentry.rules.filters.event_attribute.EventAttributeFilter",
                    "attribute": "message",
                    "match": "co",
                    "value": "test",
                },
                {
                    "id": "sentry.rules.filters.tagged_event.TaggedEventFilter",
                    "key": "test",
                    "match": "co",
                    "value": "test",
                },
                {
                    "id": "sentry.rules.filters.level.LevelFilter",
                    "match": "eq",
                    "level": "50",
                },
            ],
            actions=[
                {
                    "id": "sentry.mail.actions.NotifyEmailAction",
                    "targetType": "IssueOwners",
                    "targetIdentifier": "",
                },
                {
                    "id": "sentry.mail.actions.NotifyEmailAction",
                    "targetType": "Team",
                    "targetIdentifier": main_sentry_team["teamId"],
                },
                {
                    "id": "sentry.rules.actions.notify_event.NotifyEventAction",
                },
                {
                    "id": "sentry.integrations.slack.notify_action.SlackNotifyServiceAction",
                    "channel": "#general",
                    "workspace": slack.internal_id,
                },
            ])
        ```

        ## Import

        import using the organization, project slugs and rule id from the URL:

        https://sentry.io/organizations/[org-slug]/alerts/rules/[project-slug]/[rule-id]/details/

        ```sh
        $ pulumi import sentry:index/sentryIssueAlert:SentryIssueAlert default org-slug/project-slug/rule-id
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] action_match: Trigger actions when an event is captured by Sentry and `any` or `all` of the specified conditions happen.
        :param pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]] actions: List of actions.
        :param pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]] conditions: List of conditions.
        :param pulumi.Input[str] environment: Perform issue alert in a specific environment.
        :param pulumi.Input[str] filter_match: Trigger actions if `all`, `any`, or `none` of the specified filters match.
        :param pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]] filters: List of filters.
        :param pulumi.Input[int] frequency: Perform actions at most once every `X` minutes for this issue. Defaults to `30`.
        :param pulumi.Input[str] name: The issue alert name.
        :param pulumi.Input[str] organization: The slug of the organization the issue alert belongs to.
        :param pulumi.Input[str] project: The slug of the project to create the issue alert for.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SentryIssueAlertArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Sentry Issue Alert resource. Note that there's no public documentation for the values of conditions, filters, and actions. You can either inspect the request payload sent when creating or editing an issue alert on Sentry or inspect [Sentry's rules registry in the source code](https://github.com/getsentry/sentry/tree/master/src/sentry/rules). Since v0.11.2, you should also omit the name property of each condition, filter, and action.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_sentry as sentry
        import pulumiverse_sentry as sentry

        # Retrieve a Slack integration
        slack = sentry.get_sentry_organization_integration(organization=test["organization"],
            provider_key="slack",
            name="Slack Workspace")
        main = sentry.SentryIssueAlert("main",
            organization=main_sentry_project["organization"],
            project=main_sentry_project["id"],
            name="My issue alert",
            action_match="any",
            filter_match="any",
            frequency=30,
            conditions=[
                {
                    "id": "sentry.rules.conditions.first_seen_event.FirstSeenEventCondition",
                },
                {
                    "id": "sentry.rules.conditions.regression_event.RegressionEventCondition",
                },
                {
                    "id": "sentry.rules.conditions.event_frequency.EventFrequencyCondition",
                    "value": "100",
                    "comparisonType": "count",
                    "interval": "1h",
                },
                {
                    "id": "sentry.rules.conditions.event_frequency.EventUniqueUserFrequencyCondition",
                    "value": "100",
                    "comparisonType": "count",
                    "interval": "1h",
                },
                {
                    "id": "sentry.rules.conditions.event_frequency.EventFrequencyPercentCondition",
                    "value": "50.0",
                    "comparisonType": "count",
                    "interval": "1h",
                },
            ],
            filters=[
                {
                    "id": "sentry.rules.filters.age_comparison.AgeComparisonFilter",
                    "value": "10",
                    "time": "minute",
                    "comparison_type": "older",
                },
                {
                    "id": "sentry.rules.filters.issue_occurrences.IssueOccurrencesFilter",
                    "value": "10",
                },
                {
                    "id": "sentry.rules.filters.assigned_to.AssignedToFilter",
                    "targetType": "Team",
                    "targetIdentifier": main_sentry_team["teamId"],
                },
                {
                    "id": "sentry.rules.filters.latest_release.LatestReleaseFilter",
                },
                {
                    "id": "sentry.rules.filters.event_attribute.EventAttributeFilter",
                    "attribute": "message",
                    "match": "co",
                    "value": "test",
                },
                {
                    "id": "sentry.rules.filters.tagged_event.TaggedEventFilter",
                    "key": "test",
                    "match": "co",
                    "value": "test",
                },
                {
                    "id": "sentry.rules.filters.level.LevelFilter",
                    "match": "eq",
                    "level": "50",
                },
            ],
            actions=[
                {
                    "id": "sentry.mail.actions.NotifyEmailAction",
                    "targetType": "IssueOwners",
                    "targetIdentifier": "",
                },
                {
                    "id": "sentry.mail.actions.NotifyEmailAction",
                    "targetType": "Team",
                    "targetIdentifier": main_sentry_team["teamId"],
                },
                {
                    "id": "sentry.rules.actions.notify_event.NotifyEventAction",
                },
                {
                    "id": "sentry.integrations.slack.notify_action.SlackNotifyServiceAction",
                    "channel": "#general",
                    "workspace": slack.internal_id,
                },
            ])
        ```

        ## Import

        import using the organization, project slugs and rule id from the URL:

        https://sentry.io/organizations/[org-slug]/alerts/rules/[project-slug]/[rule-id]/details/

        ```sh
        $ pulumi import sentry:index/sentryIssueAlert:SentryIssueAlert default org-slug/project-slug/rule-id
        ```

        :param str resource_name: The name of the resource.
        :param SentryIssueAlertArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SentryIssueAlertArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 action_match: Optional[pulumi.Input[str]] = None,
                 actions: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]] = None,
                 conditions: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]] = None,
                 environment: Optional[pulumi.Input[str]] = None,
                 filter_match: Optional[pulumi.Input[str]] = None,
                 filters: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]] = None,
                 frequency: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SentryIssueAlertArgs.__new__(SentryIssueAlertArgs)

            if action_match is None and not opts.urn:
                raise TypeError("Missing required property 'action_match'")
            __props__.__dict__["action_match"] = action_match
            if actions is None and not opts.urn:
                raise TypeError("Missing required property 'actions'")
            __props__.__dict__["actions"] = actions
            if conditions is None and not opts.urn:
                raise TypeError("Missing required property 'conditions'")
            __props__.__dict__["conditions"] = conditions
            __props__.__dict__["environment"] = environment
            if filter_match is None and not opts.urn:
                raise TypeError("Missing required property 'filter_match'")
            __props__.__dict__["filter_match"] = filter_match
            __props__.__dict__["filters"] = filters
            if frequency is None and not opts.urn:
                raise TypeError("Missing required property 'frequency'")
            __props__.__dict__["frequency"] = frequency
            __props__.__dict__["name"] = name
            if organization is None and not opts.urn:
                raise TypeError("Missing required property 'organization'")
            __props__.__dict__["organization"] = organization
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            __props__.__dict__["internal_id"] = None
            __props__.__dict__["projects"] = None
        super(SentryIssueAlert, __self__).__init__(
            'sentry:index/sentryIssueAlert:SentryIssueAlert',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            action_match: Optional[pulumi.Input[str]] = None,
            actions: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]] = None,
            conditions: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]] = None,
            environment: Optional[pulumi.Input[str]] = None,
            filter_match: Optional[pulumi.Input[str]] = None,
            filters: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]] = None,
            frequency: Optional[pulumi.Input[int]] = None,
            internal_id: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            organization: Optional[pulumi.Input[str]] = None,
            project: Optional[pulumi.Input[str]] = None,
            projects: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None) -> 'SentryIssueAlert':
        """
        Get an existing SentryIssueAlert resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] action_match: Trigger actions when an event is captured by Sentry and `any` or `all` of the specified conditions happen.
        :param pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]] actions: List of actions.
        :param pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]] conditions: List of conditions.
        :param pulumi.Input[str] environment: Perform issue alert in a specific environment.
        :param pulumi.Input[str] filter_match: Trigger actions if `all`, `any`, or `none` of the specified filters match.
        :param pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]] filters: List of filters.
        :param pulumi.Input[int] frequency: Perform actions at most once every `X` minutes for this issue. Defaults to `30`.
        :param pulumi.Input[str] internal_id: The internal ID for this issue alert.
        :param pulumi.Input[str] name: The issue alert name.
        :param pulumi.Input[str] organization: The slug of the organization the issue alert belongs to.
        :param pulumi.Input[str] project: The slug of the project to create the issue alert for.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] projects: Use `project` (singular) instead.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SentryIssueAlertState.__new__(_SentryIssueAlertState)

        __props__.__dict__["action_match"] = action_match
        __props__.__dict__["actions"] = actions
        __props__.__dict__["conditions"] = conditions
        __props__.__dict__["environment"] = environment
        __props__.__dict__["filter_match"] = filter_match
        __props__.__dict__["filters"] = filters
        __props__.__dict__["frequency"] = frequency
        __props__.__dict__["internal_id"] = internal_id
        __props__.__dict__["name"] = name
        __props__.__dict__["organization"] = organization
        __props__.__dict__["project"] = project
        __props__.__dict__["projects"] = projects
        return SentryIssueAlert(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="actionMatch")
    def action_match(self) -> pulumi.Output[str]:
        """
        Trigger actions when an event is captured by Sentry and `any` or `all` of the specified conditions happen.
        """
        return pulumi.get(self, "action_match")

    @property
    @pulumi.getter
    def actions(self) -> pulumi.Output[Sequence[Mapping[str, str]]]:
        """
        List of actions.
        """
        return pulumi.get(self, "actions")

    @property
    @pulumi.getter
    def conditions(self) -> pulumi.Output[Sequence[Mapping[str, str]]]:
        """
        List of conditions.
        """
        return pulumi.get(self, "conditions")

    @property
    @pulumi.getter
    def environment(self) -> pulumi.Output[str]:
        """
        Perform issue alert in a specific environment.
        """
        return pulumi.get(self, "environment")

    @property
    @pulumi.getter(name="filterMatch")
    def filter_match(self) -> pulumi.Output[str]:
        """
        Trigger actions if `all`, `any`, or `none` of the specified filters match.
        """
        return pulumi.get(self, "filter_match")

    @property
    @pulumi.getter
    def filters(self) -> pulumi.Output[Optional[Sequence[Mapping[str, str]]]]:
        """
        List of filters.
        """
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def frequency(self) -> pulumi.Output[int]:
        """
        Perform actions at most once every `X` minutes for this issue. Defaults to `30`.
        """
        return pulumi.get(self, "frequency")

    @property
    @pulumi.getter(name="internalId")
    def internal_id(self) -> pulumi.Output[str]:
        """
        The internal ID for this issue alert.
        """
        return pulumi.get(self, "internal_id")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The issue alert name.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def organization(self) -> pulumi.Output[str]:
        """
        The slug of the organization the issue alert belongs to.
        """
        return pulumi.get(self, "organization")

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[str]:
        """
        The slug of the project to create the issue alert for.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter
    @_utilities.deprecated("""Use `project` (singular) instead.""")
    def projects(self) -> pulumi.Output[Sequence[str]]:
        """
        Use `project` (singular) instead.
        """
        return pulumi.get(self, "projects")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetSentryIssueAlertResult',
    'AwaitableGetSentryIssueAlertResult',
    'get_sentry_issue_alert',
    'get_sentry_issue_alert_output',
]

@pulumi.output_type
class GetSentryIssueAlertResult:
    """
    A collection of values returned by getSentryIssueAlert.
    """
    def __init__(__self__, action_match=None, actions=None, conditions=None, environment=None, filter_match=None, filters=None, frequency=None, id=None, internal_id=None, name=None, organization=None, project=None):
        if action_match and not isinstance(action_match, str):
            raise TypeError("Expected argument 'action_match' to be a str")
        pulumi.set(__self__, "action_match", action_match)
        if actions and not isinstance(actions, list):
            raise TypeError("Expected argument 'actions' to be a list")
        pulumi.set(__self__, "actions", actions)
        if conditions and not isinstance(conditions, list):
            raise TypeError("Expected argument 'conditions' to be a list")
        pulumi.set(__self__, "conditions", conditions)
        if environment and not isinstance(environment, str):
            raise TypeError("Expected argument 'environment' to be a str")
        pulumi.set(__self__, "environment", environment)
        if filter_match and not isinstance(filter_match, str):
            raise TypeError("Expected argument 'filter_match' to be a str")
        pulumi.set(__self__, "filter_match", filter_match)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if frequency and not isinstance(frequency, int):
            raise TypeError("Expected argument 'frequency' to be a int")
        pulumi.set(__self__, "frequency", frequency)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if internal_id and not isinstance(internal_id, str):
            raise TypeError("Expected argument 'internal_id' to be a str")
        pulumi.set(__self__, "internal_id", internal_id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if organization and not isinstance(organization, str):
            raise TypeError("Expected argument 'organization' to be a str")
        pulumi.set(__self__, "organization", organization)
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        pulumi.set(__self__, "project", project)

    @property
    @pulumi.getter(name="actionMatch")
    def action_match(self) -> str:
        """
        Trigger actions when an event is captured by Sentry and `any` or `all` of the specified conditions happen.
        """
        return pulumi.get(self, "action_match")

    @property
    @pulumi.getter
    def actions(self) -> Sequence[Mapping[str, str]]:
        """
        List of actions.
        """
        return pulumi.get(self, "actions")

    @property
    @pulumi.getter
    def conditions(self) -> Sequence[Mapping[str, str]]:
        """
        List of conditions.
        """
        return pulumi.get(self, "conditions")

    @property
    @pulumi.getter
    def environment(self) -> str:
        """
        Perform issue alert in a specific environment.
        """
        return pulumi.get(self, "environment")

    @property
    @pulumi.getter(name="filterMatch")
    def filter_match(self) -> str:
        """
        Trigger actions if `all`, `any`, or `none` of the specified filters match.
        """
        return pulumi.get(self, "filter_match")

    @property
    @pulumi.getter
    def filters(self) -> Sequence[Mapping[str, str]]:
        """
        List of filters.
        """
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def frequency(self) -> int:
        """
        Perform actions at most once every `X` minutes for this issue. Defaults to `30`.
        """
        return pulumi.get(self, "frequency")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="internalId")
    def internal_id(self) -> str:
        """
        The internal ID for this issue alert.
        """
        return pulumi.get(self, "internal_id")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The issue alert name.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def organization(self) -> str:
        """
        The slug of the organization the issue alert belongs to.
        """
        return pulumi.get(self, "organization")

    @property
    @pulumi.getter
    def project(self) -> str:
        """
        The slug of the project the issue alert belongs to.
        """
        return pulumi.get(self, "project")


class AwaitableGetSentryIssueAlertResult(GetSentryIssueAlertResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSentryIssueAlertResult(
            action_match=self.action_match,
            actions=self.actions,
            conditions=self.conditions,
            environment=self.environment,
            filter_match=self.filter_match,
            filters=self.filters,
            frequency=self.frequency,
            id=self.id,
            internal_id=self.internal_id,
            name=self.name,
            organization=self.organization,
            project=self.project)


def get_sentry_issue_alert(internal_id: Optional[str] = None,
                           organization: Optional[str] = None,
                           project: Optional[str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSentryIssueAlertResult:
    """
    Sentry Issue Alert data source. As the object structure of `conditions`, `filters`, and `actions` are undocumented, a tip is to set up an Issue Alert via the Web UI, and use this data source to copy its object structure to your resources.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_sentry as sentry
    import pulumiverse_sentry as sentry

    # Retrieve an Issue Alert
    # URL format: https://sentry.io/organizations/[organization]/alerts/rules/[project]/[internal_id]/details/
    original = sentry.get_sentry_issue_alert(organization="my-organization",
        project="my-project",
        internal_id="42")
    # Create a copy of an Issue Alert
    copy = sentry.SentryIssueAlert("copy",
        organization=original.organization,
        project=original.project,
        name=f"{original.name}-copy",
        action_match=original.action_match,
        filter_match=original.filter_match,
        frequency=original.frequency,
        conditions=original.conditions,
        filters=original.filters,
        actions=original.actions)
    ```


    :param str internal_id: The internal ID for this issue alert.
    :param str organization: The slug of the organization the issue alert belongs to.
    :param str project: The slug of the project the issue alert belongs to.
    """
    __args__ = dict()
    __args__['internalId'] = internal_id
    __args__['organization'] = organization
    __args__['project'] = project
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('sentry:index/getSentryIssueAlert:getSentryIssueAlert', __args__, opts=opts, typ=GetSentryIssueAlertResult).value

    return AwaitableGetSentryIssueAlertResult(
        action_match=pulumi.get(__ret__, 'action_match'),
        actions=pulumi.get(__ret__, 'actions'),
        conditions=pulumi.get(__ret__, 'conditions'),
        environment=pulumi.get(__ret__, 'environment'),
        filter_match=pulumi.get(__ret__, 'filter_match'),
        filters=pulumi.get(__ret__, 'filters'),
        frequency=pulumi.get(__ret__, 'frequency'),
        id=pulumi.get(__ret__, 'id'),
        internal_id=pulumi.get(__ret__, 'internal_id'),
        name=pulumi.get(__ret__, 'name'),
        organization=pulumi.get(__ret__, 'organization'),
        project=pulumi.get(__ret__, 'project'))
def get_sentry_issue_alert_output(internal_id: Optional[pulumi.Input[str]] = None,
                                  organization: Optional[pulumi.Input[str]] = None,
                                  project: Optional[pulumi.Input[str]] = None,
                                  opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetSentryIssueAlertResult]:
    """
    Sentry Issue Alert data source. As the object structure of `conditions`, `filters`, and `actions` are undocumented, a tip is to set up an Issue Alert via the Web UI, and use this data source to copy its object structure to your resources.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_sentry as sentry
    import pulumiverse_sentry as sentry

    # Retrieve an Issue Alert
    # URL format: https://sentry.io/organizations/[organization]/alerts/rules/[project]/[internal_id]/details/
    original = sentry.get_sentry_issue_alert(organization="my-organization",
        project="my-project",
        internal_id="42")
    # Create a copy of an Issue Alert
    copy = sentry.SentryIssueAlert("copy",
        organization=original.organization,
        project=original.project,
        name=f"{original.name}-copy",
        action_match=original.action_match,
        filter_match=original.filter_match,
        frequency=original.frequency,
        conditions=original.conditions,
        filters=original.filters,
        actions=original.actions)
    ```


    :param str internal_id: The internal ID for this issue alert.
    :param str organization: The slug of the organization the issue alert belongs to.
    :param str project: The slug of the project the issue alert belongs to.
    """
    __args__ = dict()
    __args__['internalId'] = internal_id
    __args__['organization'] = organization
    __args__['project'] = project
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('sentry:index/getSentryIssueAlert:getSentryIssueAlert', __args__, opts=opts, typ=GetSentryIssueAlertResult)
    return __ret__.apply(lambda __response__: GetSentryIssueAlertResult(
        action_match=pulumi.get(__response__, 'action_match'),
        actions=pulumi.get(__response__, 'actions'),
        conditions=pulumi.get(__response__, 'conditions'),
        environment=pulumi.get(__response__, 'environment'),
        filter_match=pulumi.get(__response__, 'filter_match'),
        filters=pulumi.get(__response__, 'filters'),
        frequency=pulumi.get(__response__, 'frequency'),
        id=pulumi.get(__response__, 'id'),
        internal_id=pulumi.get(__response__, 'internal_id'),
        name=pulumi.get(__response__, 'name'),
        organization=pulumi.get(__response__, 'organization'),
        project=pulumi.get(__response__, 'project')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetSentryMetricAlertResult',
    'AwaitableGetSentryMetricAlertResult',
    'get_sentry_metric_alert',
    'get_sentry_metric_alert_output',
]

@pulumi.output_type
class GetSentryMetricAlertResult:
    """
    A collection of values returned by getSentryMetricAlert.
    """
    def __init__(__self__, aggregate=None, dataset=None, environment=None, event_types=None, id=None, internal_id=None, name=None, organization=None, owner=None, project=None, query=None, resolve_threshold=None, threshold_type=None, time_window=None, triggers=None):
        if aggregate and not isinstance(aggregate, str):
            raise TypeError("Expected argument 'aggregate' to be a str")
        pulumi.set(__self__, "aggregate", aggregate)
        if dataset and not isinstance(dataset, str):
            raise TypeError("Expected argument 'dataset' to be a str")
        pulumi.set(__self__, "dataset", dataset)
        if environment and not isinstance(environment, str):
            raise TypeError("Expected argument 'environment' to be a str")
        pulumi.set(__self__, "environment", environment)
        if event_types and not isinstance(event_types, list):
            raise TypeError("Expected argument 'event_types' to be a list")
        pulumi.set(__self__, "event_types", event_types)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if internal_id and not isinstance(internal_id, str):
            raise TypeError("Expected argument 'internal_id' to be a str")
        pulumi.set(__self__, "internal_id", internal_id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if organization and not isinstance(organization, str):
            raise TypeError("Expected argument 'organization' to be a str")
        pulumi.set(__self__, "organization", organization)
        if owner and not isinstance(owner, str):
            raise TypeError("Expected argument 'owner' to be a str")
        pulumi.set(__self__, "owner", owner)
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        pulumi.set(__self__, "project", project)
        if query and not isinstance(query, str):
            raise TypeError("Expected argument 'query' to be a str")
        pulumi.set(__self__, "query", query)
        if resolve_threshold and not isinstance(resolve_threshold, float):
            raise TypeError("Expected argument 'resolve_threshold' to be a float")
        pulumi.set(__self__, "resolve_threshold", resolve_threshold)
        if threshold_type and not isinstance(threshold_type, int):
            raise TypeError("Expected argument 'threshold_type' to be a int")
        pulumi.set(__self__, "threshold_type", threshold_type)
        if time_window and not isinstance(time_window, float):
            raise TypeError("Expected argument 'time_window' to be a float")
        pulumi.set(__self__, "time_window", time_window)
        if triggers and not isinstance(triggers, list):
            raise TypeError("Expected argument 'triggers' to be a list")
        pulumi.set(__self__, "triggers", triggers)

    @property
    @pulumi.getter
    def aggregate(self) -> str:
        return pulumi.get(self, "aggregate")

    @property
    @pulumi.getter
    def dataset(self) -> str:
        return pulumi.get(self, "dataset")

    @property
    @pulumi.getter
    def environment(self) -> str:
        return pulumi.get(self, "environment")

    @property
    @pulumi.getter(name="eventTypes")
    def event_types(self) -> Sequence[str]:
        """
        The events type of dataset.
        """
        return pulumi.get(self, "event_types")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="internalId")
    def internal_id(self) -> str:
        """
        The internal ID for this metric alert.
        """
        return pulumi.get(self, "internal_id")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The metric alert name.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def organization(self) -> str:
        """
        The slug of the organization the metric alert belongs to.
        """
        return pulumi.get(self, "organization")

    @property
    @pulumi.getter
    def owner(self) -> str:
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter
    def project(self) -> str:
        """
        The slug of the project the metric alert belongs to.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter
    def query(self) -> str:
        return pulumi.get(self, "query")

    @property
    @pulumi.getter(name="resolveThreshold")
    def resolve_threshold(self) -> float:
        return pulumi.get(self, "resolve_threshold")

    @property
    @pulumi.getter(name="thresholdType")
    def threshold_type(self) -> int:
        return pulumi.get(self, "threshold_type")

    @property
    @pulumi.getter(name="timeWindow")
    def time_window(self) -> float:
        return pulumi.get(self, "time_window")

    @property
    @pulumi.getter
    def triggers(self) -> Sequence['outputs.GetSentryMetricAlertTriggerResult']:
        return pulumi.get(self, "triggers")


class AwaitableGetSentryMetricAlertResult(GetSentryMetricAlertResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSentryMetricAlertResult(
            aggregate=self.aggregate,
            dataset=self.dataset,
            environment=self.environment,
            event_types=self.event_types,
            id=self.id,
            internal_id=self.internal_id,
            name=self.name,
            organization=self.organization,
            owner=self.owner,
            project=self.project,
            query=self.query,
            resolve_threshold=self.resolve_threshold,
            threshold_type=self.threshold_type,
            time_window=self.time_window,
            triggers=self.triggers)


def get_sentry_metric_alert(internal_id: Optional[str] = None,
                            organization: Optional[str] = None,
                            project: Optional[str] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSentryMetricAlertResult:
    """
    ## Example Usage


    :param str internal_id: The internal ID for this metric alert.
    :param str organization: The slug of the organization the metric alert belongs to.
    :param str project: The slug of the project the metric alert belongs to.
    """
    __args__ = dict()
    __args__['internalId'] = internal_id
    __args__['organization'] = organization
    __args__['project'] = project
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('sentry:index/getSentryMetricAlert:getSentryMetricAlert', __args__, opts=opts, typ=GetSentryMetricAlertResult).value

    return AwaitableGetSentryMetricAlertResult(
        aggregate=pulumi.get(__ret__, 'aggregate'),
        dataset=pulumi.get(__ret__, 'dataset'),
        environment=pulumi.get(__ret__, 'environment'),
        event_types=pulumi.get(__ret__, 'event_types'),
        id=pulumi.get(__ret__, 'id'),
        internal_id=pulumi.get(__ret__, 'internal_id'),
        name=pulumi.get(__ret__, 'name'),
        organization=pulumi.get(__ret__, 'organization'),
        owner=pulumi.get(__ret__, 'owner'),
        project=pulumi.get(__ret__, 'project'),
        query=pulumi.get(__ret__, 'query'),
        resolve_threshold=pulumi.get(__ret__, 'resolve_threshold'),
        threshold_type=pulumi.get(__ret__, 'threshold_type'),
        time_window=pulumi.get(__ret__, 'time_window'),
        triggers=pulumi.get(__ret__, 'triggers'))
def get_sentry_metric_alert_output(internal_id: Optional[pulumi.Input[str]] = None,
                                   organization: Optional[pulumi.Input[str]] = None,
                                   project: Optional[pulumi.Input[str]] = None,
                                   opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetSentryMetricAlertResult]:
    """
    ## Example Usage


    :param str internal_id: The internal ID for this metric alert.
    :param str organization: The slug of the organization the metric alert belongs to.
    :param str project: The slug of the project the metric alert belongs to.
    """
    __args__ = dict()
    __args__['internalId'] = internal_id
    __args__['organization'] = organization
    __args__['project'] = project
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('sentry:index/getSentryMetricAlert:getSentryMetricAlert', __args__, opts=opts, typ=GetSentryMetricAlertResult)
    return __ret__.apply(lambda __response__: GetSentryMetricAlertResult(
        aggregate=pulumi.get(__response__, 'aggregate'),
        dataset=pulumi.get(__response__, 'dataset'),
        environment=pulumi.get(__response__, 'environment'),
        event_types=pulumi.get(__response__, 'event_types'),
        id=pulumi.get(__response__, 'id'),
        internal_id=pulumi.get(__response__, 'internal_id'),
        name=pulumi.get(__response__, 'name'),
        organization=pulumi.get(__response__, 'organization'),
        owner=pulumi.get(__response__, 'owner'),
        project=pulumi.get(__response__, 'project'),
        query=pulumi.get(__response__, 'query'),
        resolve_threshold=pulumi.get(__response__, 'resolve_threshold'),
        threshold_type=pulumi.get(__response__, 'threshold_type'),
        time_window=pulumi.get(__response__, 'time_window'),
        triggers=pulumi.get(__response__, 'triggers')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['SentryRuleArgs', 'SentryRule']

@pulumi.input_type
class SentryRuleArgs:
    def __init__(__self__, *,
                 action_match: pulumi.Input[str],
                 actions: pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]],
                 conditions: pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]],
                 filter_match: pulumi.Input[str],
                 frequency: pulumi.Input[int],
                 organization: pulumi.Input[str],
                 project: pulumi.Input[str],
                 environment: Optional[pulumi.Input[str]] = None,
                 filters: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a SentryRule resource.
        :param pulumi.Input[str] action_match: Trigger actions when an event is captured by Sentry and `any` or `all` of the specified conditions happen.
        :param pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]] actions: List of actions.
        :param pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]] conditions: List of conditions.
        :param pulumi.Input[str] filter_match: Trigger actions if `all`, `any`, or `none` of the specified filters match.
        :param pulumi.Input[int] frequency: Perform actions at most once every `X` minutes for this issue. Defaults to `30`.
        :param pulumi.Input[str] organization: The slug of the organization the issue alert belongs to.
        :param pulumi.Input[str] project: The slug of the project to create the issue alert for.
        :param pulumi.Input[str] environment: Perform issue alert in a specific environment.
        :param pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]] filters: List of filters.
        :param pulumi.Input[str] name: The issue alert name.
        """
        pulumi.set(__self__, "action_match", action_match)
        pulumi.set(__self__, "actions", actions)
        pulumi.set(__self__, "conditions", conditions)
        pulumi.set(__self__, "filter_match", filter_match)
        pulumi.set(__self__, "frequency", frequency)
        pulumi.set(__self__, "organization", organization)
        pulumi.set(__self__, "project", project)
        if environment is not None:
            pulumi.set(__self__, "environment", environment)
        if filters is not None:
            pulumi.set(__self__, "filters", filters)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="actionMatch")
    def action_match(self) -> pulumi.Input[str]:
        """
        Trigger actions when an event is captured by Sentry and `any` or `all` of the specified conditions happen.
        """
        return pulumi.get(self, "action_match")

    @action_match.setter
    def action_match(self, value: pulumi.Input[str]):
        pulumi.set(self, "action_match", value)

    @property
    @pulumi.getter
    def actions(self) -> pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]:
        """
        List of actions.
        """
        return pulumi.get(self, "actions")

    @actions.setter
    def actions(self, value: pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]):
        pulumi.set(self, "actions", value)

    @property
    @pulumi.getter
    def conditions(self) -> pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]:
        """
        List of conditions.
        """
        return pulumi.get(self, "conditions")

    @conditions.setter
    def conditions(self, value: pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]):
        pulumi.set(self, "conditions", value)

    @property
    @pulumi.getter(name="filterMatch")
    def filter_match(self) -> pulumi.Input[str]:
        """
        Trigger actions if `all`, `any`, or `none` of the specified filters match.
        """
        return pulumi.get(self, "filter_match")

    @filter_match.setter
    def filter_match(self, value: pulumi.Input[str]):
        pulumi.set(self, "filter_match", value)

    @property
    @pulumi.getter
    def frequency(self) -> pulumi.Input[int]:
        """
        Perform actions at most once every `X` minutes for this issue. Defaults to `30`.
        """
        return pulumi.get(self, "frequency")

    @frequency.setter
    def frequency(self, value: pulumi.Input[int]):
        pulumi.set(self, "frequency", value)

    @property
    @pulumi.getter
    def organization(self) -> pulumi.Input[str]:
        """
        The slug of the organization the issue alert belongs to.
        """
        return pulumi.get(self, "organization")

    @organization.setter
    def organization(self, value: pulumi.Input[str]):
        pulumi.set(self, "organization", value)

    @property
    @pulumi.getter
    def project(self) -> pulumi.Input[str]:
        """
        The slug of the project to create the issue alert for.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[str]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter
    def environment(self) -> Optional[pulumi.Input[str]]:
        """
        Perform issue alert in a specific environment.
        """
        return pulumi.get(self, "environment")

    @environment.setter
    def environment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "environment", value)

    @property
    @pulumi.getter
    def filters(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]]:
        """
        List of filters.
        """
        return pulumi.get(self, "filters")

    @filters.setter
    def filters(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]]):
        pulumi.set(self, "filters", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The issue alert name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _SentryRuleState:
    def __init__(__self__, *,
                 action_match: Optional[pulumi.Input[str]] = None,
                 actions: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]] = None,
                 conditions: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]] = None,
                 environment: Optional[pulumi.Input[str]] = None,
                 filter_match: Optional[pulumi.Input[str]] = None,
                 filters: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]] = None,
                 frequency: Optional[pulumi.Input[int]] = None,
                 internal_id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 projects: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering SentryRule resources.
        :param pulumi.Input[str] action_match: Trigger actions when an event is captured by Sentry and `any` or `all` of the specified conditions happen.
        :param pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]] actions: List of actions.
        :param pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]] conditions: List of conditions.
        :param pulumi.Input[str] environment: Perform issue alert in a specific environment.
        :param pulumi.Input[str] filter_match: Trigger actions if `all`, `any`, or `none` of the specified filters match.
        :param pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]] filters: List of filters.
        :param pulumi.Input[int] frequency: Perform actions at most once every `X` minutes for this issue. Defaults to `30`.
        :param pulumi.Input[str] internal_id: The internal ID for this issue alert.
        :param pulumi.Input[str] name: The issue alert name.
        :param pulumi.Input[str] organization: The slug of the organization the issue alert belongs to.
        :param pulumi.Input[str] project: The slug of the project to create the issue alert for.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] projects: Use `project` (singular) instead.
        """
        if action_match is not None:
            pulumi.set(__self__, "action_match", action_match)
        if actions is not None:
            pulumi.set(__self__, "actions", actions)
        if conditions is not None:
            pulumi.set(__self__, "conditions", conditions)
        if environment is not None:
            pulumi.set(__self__, "environment", environment)
        if filter_match is not None:
            pulumi.set(__self__, "filter_match", filter_match)
        if filters is not None:
            pulumi.set(__self__, "filters", filters)
        if frequency is not None:
            pulumi.set(__self__, "frequency", frequency)
        if internal_id is not None:
            pulumi.set(__self__, "internal_id", internal_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if organization is not None:
            pulumi.set(__self__, "organization", organization)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if projects is not None:
            warnings.warn("""Use `project` (singular) instead.""", DeprecationWarning)
            pulumi.log.warn("""projects is deprecated: Use `project` (singular) instead.""")
        if projects is not None:
            pulumi.set(__self__, "projects", projects)

    @property
    @pulumi.getter(name="actionMatch")
    def action_match(self) -> Optional[pulumi.Input[str]]:
        """
        Trigger actions when an event is captured by Sentry and `any` or `all` of the specified conditions happen.
        """
        return pulumi.get(self, "action_match")

    @action_match.setter
    def action_match(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "action_match", value)

    @property
    @pulumi.getter
    def actions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]]:
        """
        List of actions.
        """
        return pulumi.get(self, "actions")

    @actions.setter
    def actions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]]):
        pulumi.set(self, "actions", value)

    @property
    @pulumi.getter
    def conditions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]]:
        """
        List of conditions.
        """
        return pulumi.get(self, "conditions")

    @conditions.setter
    def conditions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]]):
        pulumi.set(self, "conditions", value)

    @property
    @pulumi.getter
    def environment(self) -> Optional[pulumi.Input[str]]:
        """
        Perform issue alert in a specific environment.
        """
        return pulumi.get(self, "environment")

    @environment.setter
    def environment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "environment", value)

    @property
    @pulumi.getter(name="filterMatch")
    def filter_match(self) -> Optional[pulumi.Input[str]]:
        """
        Trigger actions if `all`, `any`, or `none` of the specified filters match.
        """
        return pulumi.get(self, "filter_match")

    @filter_match.setter
    def filter_match(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "filter_match", value)

    @property
    @pulumi.getter
    def filters(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]]:
        """
        List of filters.
        """
        return pulumi.get(self, "filters")

    @filters.setter
    def filters(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]]):
        pulumi.set(self, "filters", value)

    @property
    @pulumi.getter
    def frequency(self) -> Optional[pulumi.Input[int]]:
        """
        Perform actions at most once every `X` minutes for this issue. Defaults to `30`.
        """
        return pulumi.get(self, "frequency")

    @frequency.setter
    def frequency(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "frequency", value)

    @property
    @pulumi.getter(name="internalId")
    def internal_id(self) -> Optional[pulumi.Input[str]]:
        """
        The internal ID for this issue alert.
        """
        return pulumi.get(self, "internal_id")

    @internal_id.setter
    def internal_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "internal_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The issue alert name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def organization(self) -> Optional[pulumi.Input[str]]:
        """
        The slug of the organization the issue alert belongs to.
        """
        return pulumi.get(self, "organization")

    @organization.setter
    def organization(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "organization", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[str]]:
        """
        The slug of the project to create the issue alert for.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter
    @_utilities.deprecated("""Use `project` (singular) instead.""")
    def projects(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Use `project` (singular) instead.
        """
        return pulumi.get(self, "projects")

    @projects.setter
    def projects(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "projects", value)


class SentryRule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 action_match: Optional[pulumi.Input[str]] = None,
                 actions: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]] = None,
                 conditions: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]] = None,
                 environment: Optional[pulumi.Input[str]] = None,
                 filter_match: Optional[pulumi.Input[str]] = None,
                 filters: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]] = None,
                 frequency: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        > **WARNING:** This resource is deprecated and will be removed in the next major version. Use the `SentryIssueAlert` resource instead.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] action_match: Trigger actions when an event is captured by Sentry and `any` or `all` of the specified conditions happen.
        :param pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]] actions: List of actions.
        :param pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]] conditions: List of conditions.
        :param pulumi.Input[str] environment: Perform issue alert in a specific environment.
        :param pulumi.Input[str] filter_match: Trigger actions if `all`, `any`, or `none` of the specified filters match.
        :param pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]] filters: List of filters.
        :param pulumi.Input[int] frequency: Perform actions at most once every `X` minutes for this issue. Defaults to `30`.
        :param pulumi.Input[str] name: The issue alert name.
        :param pulumi.Input[str] organization: The slug of the organization the issue alert belongs to.
        :param pulumi.Input[str] project: The slug of the project to create the issue alert for.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SentryRuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        > **WARNING:** This resource is deprecated and will be removed in the next major version. Use the `SentryIssueAlert` resource instead.

        :param str resource_name: The name of the resource.
        :param SentryRuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SentryRuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 action_match: Optional[pulumi.Input[str]] = None,
                 actions: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]] = None,
                 conditions: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]] = None,
                 environment: Optional[pulumi.Input[str]] = None,
                 filter_match: Optional[pulumi.Input[str]] = None,
                 filters: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]] = None,
                 frequency: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SentryRuleArgs.__new__(SentryRuleArgs)

            if action_match is None and not opts.urn:
                raise TypeError("Missing required property 'action_match'")
            __props__.__dict__["action_match"] = action_match
            if actions is None and not opts.urn:
                raise TypeError("Missing required property 'actions'")
            __props__.__dict__["actions"] = actions
            if conditions is None and not opts.urn:
                raise TypeError("Missing required property 'conditions'")
            __props__.__dict__["conditions"] = conditions
            __props__.__dict__["environment"] = environment
            if filter_match is None and not opts.urn:
                raise TypeError("Missing required property 'filter_match'")
            __props__.__dict__["filter_match"] = filter_match
            __props__.__dict__["filters"] = filters
            if frequency is None and not opts.urn:
                raise TypeError("Missing required property 'frequency'")
            __props__.__dict__["frequency"] = frequency
            __props__.__dict__["name"] = name
            if organization is None and not opts.urn:
                raise TypeError("Missing required property 'organization'")
            __props__.__dict__["organization"] = organization
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            __props__.__dict__["internal_id"] = None
            __props__.__dict__["projects"] = None
        super(SentryRule, __self__).__init__(
            'sentry:index/sentryRule:SentryRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            action_match: Optional[pulumi.Input[str]] = None,
            actions: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]] = None,
            conditions: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]] = None,
            environment: Optional[pulumi.Input[str]] = None,
            filter_match: Optional[pulumi.Input[str]] = None,
            filters: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]] = None,
            frequency: Optional[pulumi.Input[int]] = None,
            internal_id: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            organization: Optional[pulumi.Input[str]] = None,
            project: Optional[pulumi.Input[str]] = None,
            projects: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None) -> 'SentryRule':
        """
        Get an existing SentryRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] action_match: Trigger actions when an event is captured by Sentry and `any` or `all` of the specified conditions happen.
        :param pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]] actions: List of actions.
        :param pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]] conditions: List of conditions.
        :param pulumi.Input[str] environment: Perform issue alert in a specific environment.
        :param pulumi.Input[str] filter_match: Trigger actions if `all`, `any`, or `none` of the specified filters match.
        :param pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]] filters: List of filters.
        :param pulumi.Input[int] frequency: Perform actions at most once every `X` minutes for this issue. Defaults to `30`.
        :param pulumi.Input[str] internal_id: The internal ID for this issue alert.
        :param pulumi.Input[str] name: The issue alert name.
        :param pulumi.Input[str] organization: The slug of the organization the issue alert belongs to.
        :param pulumi.Input[str] project: The slug of the project to create the issue alert for.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] projects: Use `project` (singular) instead.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SentryRuleState.__new__(_SentryRuleState)

        __props__.__dict__["action_match"] = action_match
        __props__.__dict__["actions"] = actions
        __props__.__dict__["conditions"] = conditions
        __props__.__dict__["environment"] = environment
        __props__.__dict__["filter_match"] = filter_match
        __props__.__dict__["filters"] = filters
        __props__.__dict__["frequency"] = frequency
        __props__.__dict__["internal_id"] = internal_id
        __props__.__dict__["name"] = name
        __props__.__dict__["organization"] = organization
        __props__.__dict__["project"] = project
        __props__.__dict__["projects"] = projects
        return SentryRule(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="actionMatch")
    def action_match(self) -> pulumi.Output[str]:
        """
        Trigger actions when an event is captured by Sentry and `any` or `all` of the specified conditions happen.
        """
        return pulumi.get(self, "action_match")

    @property
    @pulumi.getter
    def actions(self) -> pulumi.Output[Sequence[Mapping[str, str]]]:
        """
        List of actions.
        """
        return pulumi.get(self, "actions")

    @property
    @pulumi.getter
    def conditions(self) -> pulumi.Output[Sequence[Mapping[str, str]]]:
        """
        List of conditions.
        """
        return pulumi.get(self, "conditions")

    @property
    @pulumi.getter
    def environment(self) -> pulumi.Output[str]:
        """
        Perform issue alert in a specific environment.
        """
        return pulumi.get(self, "environment")

    @property
    @pulumi.getter(name="filterMatch")
    def filter_match(self) -> pulumi.Output[str]:
        """
        Trigger actions if `all`, `any`, or `none` of the specified filters match.
        """
        return pulumi.get(self, "filter_match")

    @property
    @pulumi.getter
    def filters(self) -> pulumi.Output[Optional[Sequence[Mapping[str, str]]]]:
        """
        List of filters.
        """
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def frequency(self) -> pulumi.Output[int]:
        """
        Perform actions at most once every `X` minutes for this issue. Defaults to `30`.
        """
        return pulumi.get(self, "frequency")

    @property
    @pulumi.getter(name="internalId")
    def internal_id(self) -> pulumi.Output[str]:
        """
        The internal ID for this issue alert.
        """
        return pulumi.get(self, "internal_id")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The issue alert name.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def organization(self) -> pulumi.Output[str]:
        """
        The slug of the organization the issue alert belongs to.
        """
        return pulumi.get(self, "organization")

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[str]:
        """
        The slug of the project to create the issue alert for.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter
    @_utilities.deprecated("""Use `project` (singular) instead.""")
    def projects(self) -> pulumi.Output[Sequence[str]]:
        """
        Use `project` (singular) instead.
        """
        return pulumi.get(self, "projects")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['SentryDashboardArgs', 'SentryDashboard']

@pulumi.input_type
class SentryDashboardArgs:
    def __init__(__self__, *,
                 organization: pulumi.Input[str],
                 title: pulumi.Input[str],
                 widgets: Optional[pulumi.Input[Sequence[pulumi.Input['SentryDashboardWidgetArgs']]]] = None):
        """
        The set of arguments for constructing a SentryDashboard resource.
        :param pulumi.Input[str] organization: The slug of the organization the dashboard belongs to.
        :param pulumi.Input[str] title: Dashboard title.
        :param pulumi.Input[Sequence[pulumi.Input['SentryDashboardWidgetArgs']]] widgets: Dashboard widgets.
        """
        pulumi.set(__self__, "organization", organization)
        pulumi.set(__self__, "title", title)
        if widgets is not None:
            pulumi.set(__self__, "widgets", widgets)

    @property
    @pulumi.getter
    def organization(self) -> pulumi.Input[str]:
        """
        The slug of the organization the dashboard belongs to.
        """
        return pulumi.get(self, "organization")

    @organization.setter
    def organization(self, value: pulumi.Input[str]):
        pulumi.set(self, "organization", value)

    @property
    @pulumi.getter
    def title(self) -> pulumi.Input[str]:
        """
        Dashboard title.
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: pulumi.Input[str]):
        pulumi.set(self, "title", value)

    @property
    @pulumi.getter
    def widgets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SentryDashboardWidgetArgs']]]]:
        """
        Dashboard widgets.
        """
        return pulumi.get(self, "widgets")

    @widgets.setter
    def widgets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SentryDashboardWidgetArgs']]]]):
        pulumi.set(self, "widgets", value)


@pulumi.input_type
class _SentryDashboardState:
    def __init__(__self__, *,
                 internal_id: Optional[pulumi.Input[str]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 title: Optional[pulumi.Input[str]] = None,
                 widgets: Optional[pulumi.Input[Sequence[pulumi.Input['SentryDashboardWidgetArgs']]]] = None):
        """
        Input properties used for looking up and filtering SentryDashboard resources.
        :param pulumi.Input[str] internal_id: The internal ID for this dashboard.
        :param pulumi.Input[str] organization: The slug of the organization the dashboard belongs to.
        :param pulumi.Input[str] title: Dashboard title.
        :param pulumi.Input[Sequence[pulumi.Input['SentryDashboardWidgetArgs']]] widgets: Dashboard widgets.
        """
        if internal_id is not None:
            pulumi.set(__self__, "internal_id", internal_id)
        if organization is not None:
            pulumi.set(__self__, "organization", organization)
        if title is not None:
            pulumi.set(__self__, "title", title)
        if widgets is not None:
            pulumi.set(__self__, "widgets", widgets)

    @property
    @pulumi.getter(name="internalId")
    def internal_id(self) -> Optional[pulumi.Input[str]]:
        """
        The internal ID for this dashboard.
        """
        return pulumi.get(self, "internal_id")

    @internal_id.setter
    def internal_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "internal_id", value)

    @property
    @pulumi.getter
    def organization(self) -> Optional[pulumi.Input[str]]:
        """
        The slug of the organization the dashboard belongs to.
        """
        return pulumi.get(self, "organization")

    @organization.setter
    def organization(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "organization", value)

    @property
    @pulumi.getter
    def title(self) -> Optional[pulumi.Input[str]]:
        """
        Dashboard title.
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "title", value)

    @property
    @pulumi.getter
    def widgets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SentryDashboardWidgetArgs']]]]:
        """
        Dashboard widgets.
        """
        return pulumi.get(self, "widgets")

    @widgets.setter
    def widgets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SentryDashboardWidgetArgs']]]]):
        pulumi.set(self, "widgets", value)


class SentryDashboard(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 title: Optional[pulumi.Input[str]] = None,
                 widgets: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SentryDashboardWidgetArgs', 'SentryDashboardWidgetArgsDict']]]]] = None,
                 __props__=None):
        """
        Sentry Dashboard resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_sentry as sentry

        main = sentry.SentryDashboard("main",
            organization=main_sentry_organization["id"],
            title="Test dashboard",
            widgets=[
                {
                    "title": "Number of Errors",
                    "display_type": "big_number",
                    "interval": "5m",
                    "widget_type": "discover",
                    "queries": [{
                        "fields": ["count()"],
                        "aggregates": ["count()"],
                        "conditions": "!event.type:transaction",
                        "order_by": "count()",
                    }],
                    "layout": {
                        "x": 0,
                        "y": 0,
                        "w": 1,
                        "h": 1,
                        "min_h": 1,
                    },
                },
                {
                    "title": "Number of Issues",
                    "display_type": "big_number",
                    "interval": "5m",
                    "widget_type": "discover",
                    "queries": [{
                        "fields": ["count_unique(issue)"],
                        "aggregates": ["count_unique(issue)"],
                        "conditions": "!event.type:transaction",
                        "order_by": "count_unique(issue)",
                    }],
                    "layout": {
                        "x": 1,
                        "y": 0,
                        "w": 1,
                        "h": 1,
                        "min_h": 1,
                    },
                },
                {
                    "title": "Events",
                    "display_type": "line",
                    "interval": "5m",
                    "widget_type": "discover",
                    "queries": [{
                        "name": "Events",
                        "fields": ["count()"],
                        "aggregates": ["count()"],
                        "conditions": "!event.type:transaction",
                        "order_by": "count()",
                    }],
                    "layout": {
                        "x": 2,
                        "y": 0,
                        "w": 4,
                        "h": 2,
                        "min_h": 2,
                    },
                },
                {
                    "title": "Affected Users",
                    "display_type": "line",
                    "interval": "5m",
                    "widget_type": "discover",
                    "queries": [
                        {
                            "name": "Known Users",
                            "fields": ["count_unique(user)"],
                            "aggregates": ["count_unique(user)"],
                            "conditions": "has:user.email !event.type:transaction",
                            "order_by": "count_unique(user)",
                        },
                        {
                            "name": "Anonymous Users",
                            "fields": ["count_unique(user)"],
                            "aggregates": ["count_unique(user)"],
                            "conditions": "!has:user.email !event.type:transaction",
                            "order_by": "count_unique(user)",
                        },
                    ],
                    "layout": {
                        "x": 1,
                        "y": 2,
                        "w": 1,
                        "h": 2,
                        "min_h": 2,
                    },
                },
                {
                    "title": "Handled vs. Unhandled",
                    "display_type": "line",
                    "interval": "5m",
                    "widget_type": "discover",
                    "queries": [
                        {
                            "name": "Handled",
                            "fields": ["count()"],
                            "aggregates": ["count()"],
                            "conditions": "error.handled:true",
                            "order_by": "count()",
                        },
                        {
                            "name": "Unhandled",
                            "fields": ["count()"],
                            "aggregates": ["count()"],
                            "conditions": "error.handled:false",
                            "order_by": "count()",
                        },
                    ],
                    "layout": {
                        "x": 0,
                        "y": 2,
                        "w": 1,
                        "h": 2,
                        "min_h": 2,
                    },
                },
                {
                    "title": "Errors by Country",
                    "display_type": "world_map",
                    "interval": "5m",
                    "widget_type": "discover",
                    "queries": [{
                        "fields": ["count()"],
                        "aggregates": ["count()"],
                        "conditions": "!event.type:transaction has:geo.country_code",
                        "order_by": "count()",
                    }],
                    "layout": {
                        "x": 4,
                        "y": 6,
                        "w": 2,
                        "h": 4,
                        "min_h": 2,
                    },
                },
                {
                    "title": "High Throughput Transactions",
                    "display_type": "table",
                    "interval": "5m",
                    "widget_type": "discover",
                    "queries": [{
                        "fields": [
                            "count()",
                            "transaction",
                        ],
                        "aggregates": ["count()"],
                        "columns": ["transaction"],
                        "conditions": "!event.type:error",
                        "order_by": "-count()",
                    }],
                    "layout": {
                        "x": 0,
                        "y": 6,
                        "w": 2,
                        "h": 4,
                        "min_h": 2,
                    },
                },
                {
                    "title": "Errors by Browser",
                    "display_type": "table",
                    "interval": "5m",
                    "widget_type": "discover",
                    "queries": [{
                        "fields": [
                            "browser.name",
                            "count()",
                        ],
                        "aggregates": ["count()"],
                        "columns": ["browser.name"],
                        "conditions": "!event.type:transaction has:browser.name",
                        "order_by": "-count()",
                    }],
                    "layout": {
                        "x": 5,
                        "y": 2,
                        "w": 1,
                        "h": 4,
                        "min_h": 2,
                    },
                },
                {
                    "title": "Overall User Misery",
                    "display_type": "big_number",
                    "interval": "5m",
                    "widget_type": "discover",
                    "queries": [{
                        "fields": ["user_misery(300)"],
                        "aggregates": ["user_misery(300)"],
                    }],
                    "layout": {
                        "x": 0,
                        "y": 1,
                        "w": 1,
                        "h": 1,
                        "min_h": 1,
                    },
                },
                {
                    "title": "Overall Apdex",
                    "display_type": "big_number",
                    "interval": "5m",
                    "widget_type": "discover",
                    "queries": [{
                        "fields": ["apdex(300)"],
                        "aggregates": ["apdex(300)"],
                    }],
                    "layout": {
                        "x": 1,
                        "y": 1,
                        "w": 1,
                        "h": 1,
                        "min_h": 1,
                    },
                },
                {
                    "title": "High Throughput Transactions",
                    "display_type": "top_n",
                    "interval": "5m",
                    "widget_type": "discover",
                    "queries": [{
                        "fields": [
                            "transaction",
                            "count()",
                        ],
                        "aggregates": ["count()"],
                        "columns": ["transaction"],
                        "conditions": "!event.type:error",
                        "order_by": "-count()",
                    }],
                    "layout": {
                        "x": 0,
                        "y": 4,
                        "w": 2,
                        "h": 2,
                        "min_h": 2,
                    },
                },
                {
                    "title": "Issues Assigned to Me or My Teams",
                    "display_type": "table",
                    "interval": "5m",
                    "widget_type": "issue",
                    "queries": [{
                        "fields": [
                            "assignee",
                            "issue",
                            "title",
                        ],
                        "columns": [
                            "assignee",
                            "issue",
                            "title",
                        ],
                        "conditions": "assigned_or_suggested:me is:unresolved",
                        "order_by": "priority",
                    }],
                    "layout": {
                        "x": 2,
                        "y": 2,
                        "w": 2,
                        "h": 4,
                        "min_h": 2,
                    },
                },
                {
                    "title": "Transactions Ordered by Misery",
                    "display_type": "table",
                    "interval": "5m",
                    "widget_type": "discover",
                    "queries": [{
                        "fields": [
                            "transaction",
                            "user_misery(300)",
                        ],
                        "aggregates": ["user_misery(300)"],
                        "columns": ["transaction"],
                        "order_by": "-user_misery(300)",
                    }],
                    "layout": {
                        "x": 2,
                        "y": 6,
                        "w": 2,
                        "h": 4,
                        "min_h": 2,
                    },
                },
                {
                    "title": "Errors by Browser Over Time",
                    "display_type": "top_n",
                    "interval": "5m",
                    "widget_type": "discover",
                    "queries": [{
                        "fields": [
                            "browser.name",
                            "count()",
                        ],
                        "aggregates": ["count()"],
                        "columns": ["browser.name"],
                        "conditions": "event.type:error has:browser.name",
                        "order_by": "-count()",
                    }],
                    "layout": {
                        "x": 4,
                        "y": 2,
                        "w": 1,
                        "h": 4,
                        "min_h": 2,
                    },
                },
            ])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] organization: The slug of the organization the dashboard belongs to.
        :param pulumi.Input[str] title: Dashboard title.
        :param pulumi.Input[Sequence[pulumi.Input[Union['SentryDashboardWidgetArgs', 'SentryDashboardWidgetArgsDict']]]] widgets: Dashboard widgets.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SentryDashboardArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Sentry Dashboard resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_sentry as sentry

        main = sentry.SentryDashboard("main",
            organization=main_sentry_organization["id"],
            title="Test dashboard",
            widgets=[
                {
                    "title": "Number of Errors",
                    "display_type": "big_number",
                    "interval": "5m",
                    "widget_type": "discover",
                    "queries": [{
                        "fields": ["count()"],
                        "aggregates": ["count()"],
                        "conditions": "!event.type:transaction",
                        "order_by": "count()",
                    }],
                    "layout": {
                        "x": 0,
                        "y": 0,
                        "w": 1,
                        "h": 1,
                        "min_h": 1,
                    },
                },
                {
                    "title": "Number of Issues",
                    "display_type": "big_number",
                    "interval": "5m",
                    "widget_type": "discover",
                    "queries": [{
                        "fields": ["count_unique(issue)"],
                        "aggregates": ["count_unique(issue)"],
                        "conditions": "!event.type:transaction",
                        "order_by": "count_unique(issue)",
                    }],
                    "layout": {
                        "x": 1,
                        "y": 0,
                        "w": 1,
                        "h": 1,
                        "min_h": 1,
                    },
                },
                {
                    "title": "Events",
                    "display_type": "line",
                    "interval": "5m",
                    "widget_type": "discover",
                    "queries": [{
                        "name": "Events",
                        "fields": ["count()"],
                        "aggregates": ["count()"],
                        "conditions": "!event.type:transaction",
                        "order_by": "count()",
                    }],
                    "layout": {
                        "x": 2,
                        "y": 0,
                        "w": 4,
                        "h": 2,
                        "min_h": 2,
                    },
                },
                {
                    "title": "Affected Users",
                    "display_type": "line",
                    "interval": "5m",
                    "widget_type": "discover",
                    "queries": [
                        {
                            "name": "Known Users",
                            "fields": ["count_unique(user)"],
                            "aggregates": ["count_unique(user)"],
                            "conditions": "has:user.email !event.type:transaction",
                            "order_by": "count_unique(user)",
                        },
                        {
                            "name": "Anonymous Users",
                            "fields": ["count_unique(user)"],
                            "aggregates": ["count_unique(user)"],
                            "conditions": "!has:user.email !event.type:transaction",
                            "order_by": "count_unique(user)",
                        },
                    ],
                    "layout": {
                        "x": 1,
                        "y": 2,
                        "w": 1,
                        "h": 2,
                        "min_h": 2,
                    },
                },
                {
                    "title": "Handled vs. Unhandled",
                    "display_type": "line",
                    "interval": "5m",
                    "widget_type": "discover",
                    "queries": [
                        {
                            "name": "Handled",
                            "fields": ["count()"],
                            "aggregates": ["count()"],
                            "conditions": "error.handled:true",
                            "order_by": "count()",
                        },
                        {
                            "name": "Unhandled",
                            "fields": ["count()"],
                            "aggregates": ["count()"],
                            "conditions": "error.handled:false",
                            "order_by": "count()",
                        },
                    ],
                    "layout": {
                        "x": 0,
                        "y": 2,
                        "w": 1,
                        "h": 2,
                        "min_h": 2,
                    },
                },
                {
                    "title": "Errors by Country",
                    "display_type": "world_map",
                    "interval": "5m",
                    "widget_type": "discover",
                    "queries": [{
                        "fields": ["count()"],
                        "aggregates": ["count()"],
                        "conditions": "!event.type:transaction has:geo.country_code",
                        "order_by": "count()",
                    }],
                    "layout": {
                        "x": 4,
                        "y": 6,
                        "w": 2,
                        "h": 4,
                        "min_h": 2,
                    },
                },
                {
                    "title": "High Throughput Transactions",
                    "display_type": "table",
                    "interval": "5m",
                    "widget_type": "discover",
                    "queries": [{
                        "fields": [
                            "count()",
                            "transaction",
                        ],
                        "aggregates": ["count()"],
                        "columns": ["transaction"],
                        "conditions": "!event.type:error",
                        "order_by": "-count()",
                    }],
                    "layout": {
                        "x": 0,
                        "y": 6,
                        "w": 2,
                        "h": 4,
                        "min_h": 2,
                    },
                },
                {
                    "title": "Errors by Browser",
                    "display_type": "table",
                    "interval": "5m",
                    "widget_type": "discover",
                    "queries": [{
                        "fields": [
                            "browser.name",
                            "count()",
                        ],
                        "aggregates": ["count()"],
                        "columns": ["browser.name"],
                        "conditions": "!event.type:transaction has:browser.name",
                        "order_by": "-count()",
                    }],
                    "layout": {
                        "x": 5,
                        "y": 2,
                        "w": 1,
                        "h": 4,
                        "min_h": 2,
                    },
                },
                {
                    "title": "Overall User Misery",
                    "display_type": "big_number",
                    "interval": "5m",
                    "widget_type": "discover",
                    "queries": [{
                        "fields": ["user_misery(300)"],
                        "aggregates": ["user_misery(300)"],
                    }],
                    "layout": {
                        "x": 0,
                        "y": 1,
                        "w": 1,
                        "h": 1,
                        "min_h": 1,
                    },
                },
                {
                    "title": "Overall Apdex",
                    "display_type": "big_number",
                    "interval": "5m",
                    "widget_type": "discover",
                    "queries": [{
                        "fields": ["apdex(300)"],
                        "aggregates": ["apdex(300)"],
                    }],
                    "layout": {
                        "x": 1,
                        "y": 1,
                        "w": 1,
                        "h": 1,
                        "min_h": 1,
                    },
                },
                {
                    "title": "High Throughput Transactions",
                    "display_type": "top_n",
                    "interval": "5m",
                    "widget_type": "discover",
                    "queries": [{
                        "fields": [
                            "transaction",
                            "count()",
                        ],
                        "aggregates": ["count()"],
                        "columns": ["transaction"],
                        "conditions": "!event.type:error",
                        "order_by": "-count()",
                    }],
                    "layout": {
                        "x": 0,
                        "y": 4,
                        "w": 2,
                        "h": 2,
                        "min_h": 2,
                    },
                },
                {
                    "title": "Issues Assigned to Me or My Teams",
                    "display_type": "table",
                    "interval": "5m",
                    "widget_type": "issue",
                    "queries": [{
                        "fields": [
                            "assignee",
                            "issue",
                            "title",
                        ],
                        "columns": [
                            "assignee",
                            "issue",
                            "title",
                        ],
                        "conditions": "assigned_or_suggested:me is:unresolved",
                        "order_by": "priority",
                    }],
                    "layout": {
                        "x": 2,
                        "y": 2,
                        "w": 2,
                        "h": 4,
                        "min_h": 2,
                    },
                },
                {
                    "title": "Transactions Ordered by Misery",
                    "display_type": "table",
                    "interval": "5m",
                    "widget_type": "discover",
                    "queries": [{
                        "fields": [
                            "transaction",
                            "user_misery(300)",
                        ],
                        "aggregates": ["user_misery(300)"],
                        "columns": ["transaction"],
                        "order_by": "-user_misery(300)",
                    }],
                    "layout": {
                        "x": 2,
                        "y": 6,
                        "w": 2,
                        "h": 4,
                        "min_h": 2,
                    },
                },
                {
                    "title": "Errors by Browser Over Time",
                    "display_type": "top_n",
                    "interval": "5m",
                    "widget_type": "discover",
                    "queries": [{
                        "fields": [
                            "browser.name",
                            "count()",
                        ],
                        "aggregates": ["count()"],
                        "columns": ["browser.name"],
                        "conditions": "event.type:error has:browser.name",
                        "order_by": "-count()",
                    }],
                    "layout": {
                        "x": 4,
                        "y": 2,
                        "w": 1,
                        "h": 4,
                        "min_h": 2,
                    },
                },
            ])
        ```

        :param str resource_name: The name of the resource.
        :param SentryDashboardArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SentryDashboardArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 title: Optional[pulumi.Input[str]] = None,
                 widgets: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SentryDashboardWidgetArgs', 'SentryDashboardWidgetArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SentryDashboardArgs.__new__(SentryDashboardArgs)

            if organization is None and not opts.urn:
                raise TypeError("Missing required property 'organization'")
            __props__.__dict__["organization"] = organization
            if title is None and not opts.urn:
                raise TypeError("Missing required property 'title'")
            __props__.__dict__["title"] = title
            __props__.__dict__["widgets"] = widgets
            __props__.__dict__["internal_id"] = None
        super(SentryDashboard, __self__).__init__(
            'sentry:index/sentryDashboard:SentryDashboard',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            internal_id: Optional[pulumi.Input[str]] = None,
            organization: Optional[pulumi.Input[str]] = None,
            title: Optional[pulumi.Input[str]] = None,
            widgets: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SentryDashboardWidgetArgs', 'SentryDashboardWidgetArgsDict']]]]] = None) -> 'SentryDashboard':
        """
        Get an existing SentryDashboard resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] internal_id: The internal ID for this dashboard.
        :param pulumi.Input[str] organization: The slug of the organization the dashboard belongs to.
        :param pulumi.Input[str] title: Dashboard title.
        :param pulumi.Input[Sequence[pulumi.Input[Union['SentryDashboardWidgetArgs', 'SentryDashboardWidgetArgsDict']]]] widgets: Dashboard widgets.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SentryDashboardState.__new__(_SentryDashboardState)

        __props__.__dict__["internal_id"] = internal_id
        __props__.__dict__["organization"] = organization
        __props__.__dict__["title"] = title
        __props__.__dict__["widgets"] = widgets
        return SentryDashboard(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="internalId")
    def internal_id(self) -> pulumi.Output[str]:
        """
        The internal ID for this dashboard.
        """
        return pulumi.get(self, "internal_id")

    @property
    @pulumi.getter
    def organization(self) -> pulumi.Output[str]:
        """
        The slug of the organization the dashboard belongs to.
        """
        return pulumi.get(self, "organization")

    @property
    @pulumi.getter
    def title(self) -> pulumi.Output[str]:
        """
        Dashboard title.
        """
        return pulumi.get(self, "title")

    @property
    @pulumi.getter
    def widgets(self) -> pulumi.Output[Optional[Sequence['outputs.SentryDashboardWidget']]]:
        """
        Dashboard widgets.
        """
        return pulumi.get(self, "widgets")

